import { useQuery } from "react-query";
import { fetchGuildChannels, fetchGuildTodos } from "../../api";
import { useGuild } from "../App/useGuild";
import { Todo } from "../Todo";
import { Loader } from "../Loader";
import { CreateTodo } from "../Todo/CreateTodo";

export const GuildTodos = () => {
    const guild = useGuild();

    const { isFetched, data: guildTodos } = useQuery(fetchGuildTodos(guild));
    const { data: channels } = useQuery(fetchGuildChannels(guild));

    if (!isFetched || !channels) {
        return <Loader />;
    }

    const sortedTodos = guildTodos.sort((a, b) => (a.id > b.id ? -1 : 1));

    return (
        <>
            <h2>Server</h2>
            {sortedTodos
                .filter((todo) => todo.channel_id === null)
                .map((todo) => (
                    <>
                        <Todo todo={todo} key={todo.id} />
                    </>
                ))}
            <CreateTodo channel={null} />
            {channels.map((channel) => {
                return (
                    <>
                        <h2>#{channel.name}</h2>
                        {sortedTodos
                            .filter((todo) => todo.channel_id === channel.id)
                            .map((todo) => (
                                <>
                                    <Todo todo={todo} key={todo.id} />
                                </>
                            ))}
                        <CreateTodo channel={channel.id} />
                    </>
                );
            })}
        </>
    );
};
