import { useMutation, useQueryClient } from "react-query";
import { postGuildTodo } from "../../api";
import { useGuild } from "../App/useGuild";
import { useState } from "preact/hooks";
import { useFlash } from "../App/FlashContext";
import { ICON_FLASH_TIME } from "../../consts";

export const CreateTodo = ({ channel }) => {
    const guild = useGuild();

    const [recentlyCreated, setRecentlyCreated] = useState(false);
    const [newTodo, setNewTodo] = useState({ value: "", channel_id: channel });

    const flash = useFlash();

    const queryClient = useQueryClient();
    const mutation = useMutation({
        ...postGuildTodo(guild),
        onSuccess: (data) => {
            if (data.error) {
                flash({
                    message: data.error,
                    type: "error",
                });
            } else {
                flash({
                    message: "Todo created",
                    type: "success",
                });
                queryClient.invalidateQueries({
                    queryKey: ["GUILD_TODOS", guild],
                });
                setRecentlyCreated(true);
                setTimeout(() => {
                    setRecentlyCreated(false);
                }, ICON_FLASH_TIME);
            }
        },
    });

    return (
        <div class="todo">
            <textarea
                class="input todo-input"
                onInput={(ev) => setNewTodo((todo) => ({ ...todo, value: ev.currentTarget.value }))}
            />
            <button onClick={() => mutation.mutate(newTodo)} class="button is-success save-btn">
                <span class="icon">
                    {mutation.isLoading ? (
                        <span class="icon">
                            <i class="fas fa-spin fa-cog"></i>
                        </span>
                    ) : recentlyCreated ? (
                        <span class="icon">
                            <i class="fas fa-check"></i>
                        </span>
                    ) : (
                        <span class="icon">
                            <i class="fas fa-sparkles"></i>
                        </span>
                    )}
                </span>
            </button>
        </div>
    );
};
